// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "gameconfig.h"
#include "ui_gameconfig.h"
#include "gameoption.h"

GameConfig::GameConfig(QWidget *parent) : QWidget(parent), m_ui(new Ui::GameConfig) {
	m_ui->setupUi(this);
	m_ui->bLeave->cmd = ".gx";
	m_ui->bStart->cmd = ".gs";
	connect(m_ui->bLeave, SIGNAL(cmdClicked(QString)), this, SLOT(emitCommand(QString)));
	connect(m_ui->bStart, SIGNAL(cmdClicked(QString)), this, SLOT(emitCommand(QString)));

	enabled = false;
	m_ui->bStart->setEnabled(false);
}

GameConfig::~GameConfig() {
	delete m_ui;
}

GameOption* GameConfig::getOption(QString cmd) {
	GameOption* go = 0;
	for (int i= 0; i < gameOptions.size(); i++)
		if (gameOptions.value(i)->getCommand() == cmd) return gameOptions.value(i);

	go = new GameOption(cmd, "", this);
	gameOptions.append(go);
	m_ui->options->addWidget(go);
	connect(go, SIGNAL(configChanged(QString)), this, SLOT(emitCommand(QString)));
	return go;
}

void GameConfig::emitCommand(QString cmd) {
	emit(optionChanged(cmd));
}

void GameConfig::configUpdate(QString cmd, QString text, bool value, bool edit) {
	GameOption* opt = getOption(cmd);
	disconnect(opt, SIGNAL(configChanged(QString)), this, SLOT(emitCommand(QString)));
	if (text != "")
		opt->setText(text);
	opt->setEnabled(enabled);
	opt->setChecked(value);
	connect(opt, SIGNAL(configChanged(QString)), this, SLOT(emitCommand(QString)));
}

void GameConfig::setOptionsEnabled(bool e) {
	enabled = e;
	foreach(GameOption* o, gameOptions)
		o->setEnabled(enabled);
	m_ui->bStart->setEnabled(enabled);
}

void GameConfig::changeEvent(QEvent *e) {
	QWidget::changeEvent(e);

	switch (e->type()) {
		case QEvent::LanguageChange:
			m_ui->retranslateUi(this);
			break;
		default:
		break;
	}
}
